@@ -29,13 +29,13 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Load the Perl modules.
 use POSIX qw(ttyname);
 
 # Use inline C code.
-use Inline 'C';
+#use Inline 'C';
 
 # Define the Perl BEGIN block.
 BEGIN {
@@ -646,6 +646,8 @@ Terminal emulators tested so far with the package:
 
 =over 4
 
+=item * Alacritty
+
 =item * Aterm
 
 =item * Cool Retro Term
@@ -658,10 +660,18 @@ Terminal emulators tested so far with the package:
 
 =item * kitty
 
+=item * Konsole
+
+=item * LilyTerm
+
 =item * LXTerminal
 
 =item * MATE-Terminal
 
+=item * mlterm
+
+=item * pterm
+
 =item * QTerminal
 
 =item * ROXTerm
